==> xtyping-0.6.1-py3-none-any.whl: xtyping/__init__.py <==
# -*- coding: utf-8 -*-
"""typing + typing_extensions + misc types/aliases"""
import typing

from typing import (
    IO,
    AbstractSet,
    Any,
    AnyStr,
    ByteString,
    Callable,
    Collection,
    Container,
    Dict,
    FrozenSet,
    Generator,
    Generic,
    Hashable,
    ItemsView,
    Iterable,
    Iterator,
    KeysView,
    List,
    Mapping,
    MappingView,
    MutableMapping,
    MutableSequence,
    MutableSet,
    NamedTuple,
    Optional,
    Reversible,
    Sequence,
    Set,
    Sized,
    SupportsAbs,
    SupportsBytes,
    SupportsComplex,
    SupportsFloat,
    SupportsInt,
    SupportsRound,
    Tuple,
    TypeVar,
    Union,
    ValuesView,
    cast,
    no_type_check,
    no_type_check_decorator,
)

import typing_extensions

from typing_extensions import (
    TYPE_CHECKING,
    Annotated,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ChainMap,
    ClassVar,
    Concatenate,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Final,
    IntVar,
    Literal,
    NewType,
    NoReturn,
    OrderedDict,
    ParamSpec,
    ParamSpecArgs,
    ParamSpecKwargs,
    Protocol,
    SupportsIndex,
    Text,
    Type,
    TypeAlias,
    TypedDict,
    TypeGuard,
    final,
    get_args,
    get_origin,
    get_type_hints,
    overload,
    runtime,
    runtime_checkable,
)

from xtyping._meta import __version__
from xtyping.shed import (
    _DT,
    _KT,
    _R,
    _RT,
    _T,
    _VT,
    AF,
    DT,
    FALSE,
    FN,
    KT,
    ONE,
    PT,
    RT,
    STDIN,
    STDIO,
    TRUE,
    VT,
    ZERO,
    AFn,
    AnyAsyncCallable,
    AnyCallable,
    AnyFunction,
    AnyIterable,
    AnyIterator,
    ArrayShape,
    ArrShape,
    AsyncFn,
    AsyncFuncType,
    Bytes,
    BytesPath,
    CmdArgs,
    CmdArgsType,
    D,
    DictAny,
    DictAnyAny,
    DictFloat,
    DictFloatFloat,
    DictInt,
    DictIntInt,
    DictNumber,
    DictNumberNumber,
    DictStr,
    DictStrAny,
    DictStrInt,
    DictStrStr,
    El,
    Element,
    Enum,
    EnvMap,
    EnvType,
    F,
    Flint,
    Fn,
    FsPath,
    FsPathLike,
    FuncType,
    HrTime,
    IntStr,
    IterableAny,
    IterableFloat,
    IterableInt,
    IterableNumber,
    IterableStr,
    IterableT,
    Json,
    JsonArrT,
    JsonDictT,
    JsonListT,
    JsonObjT,
    JsonPrimitive,
    JsonT,
    KeyT,
    KeyType,
    KT_co,
    KT_contra,
    L,
    ListAny,
    ListFloat,
    ListInt,
    ListListStr,
    ListNumber,
    ListStr,
    ListT,
    Lit,
    Ls,
    N,
    NoneBytes,
    NoneStr,
    NoneStrBytes,
    NoneType,
    Null,
    Number,
    OpenBinaryMode,
    OpenBinaryModeReading,
    OpenBinaryModeUpdating,
    OpenBinaryModeWriting,
    OpenTextMode,
    OpenTextModeReading,
    OpenTextModeUpdating,
    OpenTextModeWriting,
    Opt,
    OptFloat,
    OptInt,
    OptionalFloat,
    OptionalInt,
    OptionalStr,
    OptStr,
    P,
    Path,
    PathLike,
    R,
    ReturnT,
    ReturnType,
    Self,
    Seq,
    SetAny,
    SetFloat,
    SetInt,
    SetNumber,
    SetStr,
    SetT,
    ShapeType,
    StrBytes,
    StrEnum,
    StringEnum,
    StrIntFloat,
    StrOrBytesPath,
    StrPath,
    T,
    T_co,
    T_contra,
    T_ParamSpec,
    T_Retval,
    TupleStrs,
    TupleStrStr,
    Txt,
    U,
    V_co,
    ValT,
    ValType,
    VT_co,
    VT_contra,
    __all_shed__,
    __all_typing__,
    __all_typing_extensions__,
    __all_typing_extensions_future__,
    _KT_co,
    _KT_contra,
    _T_co,
    _T_contra,
    _V_co,
    _VT_co,
    _VT_contra,
    null,
)

__all__ = (
    "AF",
    "AFn",
    "AbstractSet",
    "Annotated",
    "Any",
    "AnyAsyncCallable",
    "AnyCallable",
    "AnyFunction",
    "AnyIterable",
    "AnyIterator",
    "AnyStr",
    "ArrShape",
    "ArrayShape",
    "AsyncContextManager",
    "AsyncFn",
    "AsyncFuncType",
    "AsyncGenerator",
    "AsyncIterable",
    "AsyncIterator",
    "Awaitable",
    "ByteString",
    "Bytes",
    "BytesPath",
    "Callable",
    "ChainMap",
    "ClassVar",
    "CmdArgs",
    "CmdArgsType",
    "Collection",
    "Concatenate",
    "Container",
    "ContextManager",
    "Coroutine",
    "Counter",
    "D",
    "DT",
    "DefaultDict",
    "Deque",
    "Dict",
    "DictAny",
    "DictAnyAny",
    "DictFloat",
    "DictFloatFloat",
    "DictInt",
    "DictIntInt",
    "DictNumber",
    "DictNumberNumber",
    "DictStr",
    "DictStrAny",
    "DictStrInt",
    "DictStrStr",
    "El",
    "Element",
    "Enum",
    "EnvMap",
    "EnvType",
    "F",
    "FALSE",
    "FN",
    "Final",
    "Flint",
    "Fn",
    "FrozenSet",
    "FsPath",
    "FsPathLike",
    "FuncType",
    "Generator",
    "Generic",
    "Hashable",
    "HrTime",
    "IO",
    "IntStr",
    "IntVar",
    "ItemsView",
    "Iterable",
    "IterableAny",
    "IterableFloat",
    "IterableInt",
    "IterableNumber",
    "IterableStr",
    "IterableT",
    "Iterator",
    "Json",
    "JsonArrT",
    "JsonDictT",
    "JsonListT",
    "JsonObjT",
    "JsonPrimitive",
    "JsonT",
    "KT",
    "KT_co",
    "KT_contra",
    "KeyT",
    "KeyType",
    "KeysView",
    "L",
    "List",
    "ListAny",
    "ListFloat",
    "ListInt",
    "ListListStr",
    "ListNumber",
    "ListStr",
    "ListT",
    "Lit",
    "Literal",
    "Ls",
    "Mapping",
    "MappingView",
    "MutableMapping",
    "MutableSequence",
    "MutableSet",
    "N",
    "NamedTuple",
    "NewType",
    "NoReturn",
    "NoneBytes",
    "NoneStr",
    "NoneStrBytes",
    "NoneType",
    "Null",
    "Number",
    "ONE",
    "OpenBinaryMode",
    "OpenBinaryModeReading",
    "OpenBinaryModeUpdating",
    "OpenBinaryModeWriting",
    "OpenTextMode",
    "OpenTextModeReading",
    "OpenTextModeUpdating",
    "OpenTextModeWriting",
    "Opt",
    "OptFloat",
    "OptInt",
    "OptStr",
    "Optional",
    "OptionalFloat",
    "OptionalInt",
    "OptionalStr",
    "OrderedDict",
    "P",
    "PT",
    "ParamSpec",
    "ParamSpecArgs",
    "ParamSpecKwargs",
    "Path",
    "PathLike",
    "Protocol",
    "R",
    "RT",
    "ReturnT",
    "ReturnType",
    "Reversible",
    "STDIN",
    "STDIO",
    "Self",
    "Seq",
    "Sequence",
    "Set",
    "SetAny",
    "SetFloat",
    "SetInt",
    "SetNumber",
    "SetStr",
    "SetT",
    "ShapeType",
    "Sized",
    "StrBytes",
    "StrEnum",
    "StrIntFloat",
    "StrOrBytesPath",
    "StrPath",
    "StringEnum",
    "SupportsAbs",
    "SupportsBytes",
    "SupportsComplex",
    "SupportsFloat",
    "SupportsIndex",
    "SupportsInt",
    "SupportsRound",
    "T",
    "TRUE",
    "TYPE_CHECKING",
    "T_ParamSpec",
    "T_Retval",
    "T_co",
    "T_contra",
    "Text",
    "Tuple",
    "TupleStrStr",
    "TupleStrs",
    "Txt",
    "Type",
    "TypeAlias",
    "TypeGuard",
    "TypeVar",
    "TypedDict",
    "U",
    "Union",
    "VT",
    "VT_co",
    "VT_contra",
    "V_co",
    "ValT",
    "ValType",
    "ValuesView",
    "ZERO",
    "_DT",
    "_KT",
    "_KT_co",
    "_KT_contra",
    "_R",
    "_RT",
    "_T",
    "_T_co",
    "_T_contra",
    "_VT",
    "_VT_co",
    "_VT_contra",
    "_V_co",
    "__all_shed__",
    "__all_typing__",
    "__all_typing_extensions__",
    "__all_typing_extensions_future__",
    "__version__",
    "cast",
    "final",
    "get_args",
    "get_origin",
    "get_type_hints",
    "no_type_check",
    "no_type_check_decorator",
    "null",
    "overload",
    "runtime",
    "runtime_checkable",
    "typing",
    "typing_extensions",
)

==> xtyping-0.8.1-py3-none-any.whl: xtyping/__init__.py <==
# -*- coding: utf-8 -*-
"""typing + typing_extensions + misc types/aliases"""
from __future__ import annotations

import typing

from typing import (
    IO,
    AbstractSet,
    Any,
    AnyStr,
    ByteString,
    Callable,
    Collection,
    Container,
    Dict,
    FrozenSet,
    Generator,
    Generic,
    Hashable,
    ItemsView,
    Iterable,
    Iterator,
    KeysView,
    List,
    Mapping,
    MappingView,
    MutableMapping,
    MutableSequence,
    MutableSet,
    NamedTuple,
    Optional,
    Reversible,
    Sequence,
    Set,
    Sized,
    SupportsAbs,
    SupportsBytes,
    SupportsComplex,
    SupportsFloat,
    SupportsInt,
    SupportsRound,
    Tuple,
    TypeVar,
    Union,
    ValuesView,
    cast,
    no_type_check,
    no_type_check_decorator,
)

import annotated_types
import typing_extensions

from annotated_types import (
    BaseMetadata,
    Ge,
    GroupedMetadata,
    Gt,
    Interval,
    IsDigits,
    Le,
    Len,
    LowerCase,
    Lt,
    MaxLen,
    MinLen,
    MultipleOf,
    Predicate,
    Timezone,
    UpperCase,
)
from typing_extensions import (
    TYPE_CHECKING,
    Annotated,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ChainMap,
    ClassVar,
    Concatenate,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Final,
    IntVar,
    Literal,
    NewType,
    NoReturn,
    NotRequired,
    OrderedDict,
    ParamSpec,
    ParamSpecArgs,
    ParamSpecKwargs,
    Protocol,
    Required,
    Self,
    SupportsIndex,
    Text,
    Type,
    TypeAlias,
    TypedDict,
    TypeGuard,
    TypeVarTuple,
    Unpack,
    final,
    get_args,
    get_origin,
    get_type_hints,
    overload,
    runtime,
    runtime_checkable,
)

from xtyping.__about__ import __version__
from xtyping.shed import (
    _DT,
    _KT,
    _R,
    _RT,
    _T,
    _VT,
    AF,
    DT,
    FALSE,
    FN,
    KT,
    ONE,
    PT,
    RT,
    STDIN,
    STDIO,
    TRUE,
    VT,
    ZERO,
    AFn,
    AnyAsyncCallable,
    AnyCallable,
    AnyFunction,
    AnyIterable,
    AnyIterator,
    ArrayShape,
    ArrShape,
    AsyncFn,
    AsyncFuncType,
    Bytes,
    BytesPath,
    CmdArgs,
    CmdArgsType,
    D,
    DictAny,
    DictAnyAny,
    DictFloat,
    DictFloatFloat,
    DictInt,
    DictIntInt,
    DictNumber,
    DictNumberNumber,
    DictStr,
    DictStrAny,
    DictStrInt,
    DictStrStr,
    El,
    Element,
    Enum,
    EnvMap,
    EnvType,
    F,
    Flint,
    Fn,
    FsPath,
    FsPathLike,
    FuncType,
    HrTime,
    IntStr,
    IterableAny,
    IterableFloat,
    IterableInt,
    IterableNumber,
    IterableStr,
    IterableT,
    Json,
    JsonArrT,
    JsonDictT,
    JsonListT,
    JsonObjT,
    JsonPrimitive,
    JsonT,
    KeyT,
    KeyType,
    KT_co,
    KT_contra,
    L,
    ListAny,
    ListFloat,
    ListInt,
    ListListStr,
    ListNumber,
    ListStr,
    ListT,
    Lit,
    Ls,
    N,
    NoneBytes,
    NoneStr,
    NoneStrBytes,
    NoneType,
    Null,
    Number,
    OpenBinaryMode,
    OpenBinaryModeReading,
    OpenBinaryModeUpdating,
    OpenBinaryModeWriting,
    OpenTextMode,
    OpenTextModeReading,
    OpenTextModeUpdating,
    OpenTextModeWriting,
    Opt,
    OptFloat,
    OptInt,
    OptionalFloat,
    OptionalInt,
    OptionalStr,
    OptStr,
    P,
    Path,
    PathLike,
    PathLikeAny,
    PathLikeBytes,
    PathLikeStr,
    R,
    ReturnT,
    ReturnType,
    Seq,
    SetAny,
    SetFloat,
    SetInt,
    SetNumber,
    SetStr,
    SetT,
    ShapeType,
    StrBytes,
    StrEnum,
    StringEnum,
    StrIntFloat,
    StrOrBytesPath,
    StrPath,
    T,
    T_co,
    T_contra,
    T_ParamSpec,
    T_Retval,
    TupleStrs,
    TupleStrStr,
    Txt,
    U,
    V_co,
    ValT,
    ValType,
    VT_co,
    VT_contra,
    __all_annotated_types__,
    __all_shed__,
    __all_typing__,
    __all_typing_extensions__,
    __all_typing_extensions_future__,
    _KT_co,
    _KT_contra,
    _T_co,
    _T_contra,
    _V_co,
    _VT_co,
    _VT_contra,
    null,
)

__all__ = (
    "AF",
    "AFn",
    "AbstractSet",
    "Annotated",
    "Any",
    "AnyAsyncCallable",
    "AnyCallable",
    "AnyFunction",
    "AnyIterable",
    "AnyIterator",
    "AnyStr",
    "ArrShape",
    "ArrayShape",
    "AsyncContextManager",
    "AsyncFn",
    "AsyncFuncType",
    "AsyncGenerator",
    "AsyncIterable",
    "AsyncIterator",
    "Awaitable",
    "BaseMetadata",
    "ByteString",
    "Bytes",
    "BytesPath",
    "Callable",
    "ChainMap",
    "ClassVar",
    "CmdArgs",
    "CmdArgsType",
    "Collection",
    "Concatenate",
    "Container",
    "ContextManager",
    "Coroutine",
    "Counter",
    "D",
    "DT",
    "DefaultDict",
    "Deque",
    "Dict",
    "DictAny",
    "DictAnyAny",
    "DictFloat",
    "DictFloatFloat",
    "DictInt",
    "DictIntInt",
    "DictNumber",
    "DictNumberNumber",
    "DictStr",
    "DictStrAny",
    "DictStrInt",
    "DictStrStr",
    "El",
    "Element",
    "Enum",
    "EnvMap",
    "EnvType",
    "F",
    "FALSE",
    "FN",
    "Final",
    "Flint",
    "Fn",
    "FrozenSet",
    "FsPath",
    "FsPathLike",
    "FuncType",
    "Ge",
    "Generator",
    "Generic",
    "GroupedMetadata",
    "Gt",
    "Hashable",
    "HrTime",
    "IO",
    "IntStr",
    "IntVar",
    "Interval",
    "IsDigits",
    "ItemsView",
    "Iterable",
    "IterableAny",
    "IterableFloat",
    "IterableInt",
    "IterableNumber",
    "IterableStr",
    "IterableT",
    "Iterator",
    "Json",
    "JsonArrT",
    "JsonDictT",
    "JsonListT",
    "JsonObjT",
    "JsonPrimitive",
    "JsonT",
    "KT",
    "KT_co",
    "KT_contra",
    "KeyT",
    "KeyType",
    "KeysView",
    "L",
    "Le",
    "Len",
    "List",
    "ListAny",
    "ListFloat",
    "ListInt",
    "ListListStr",
    "ListNumber",
    "ListStr",
    "ListT",
    "Lit",
    "Literal",
    "LowerCase",
    "Ls",
    "Lt",
    "Mapping",
    "MappingView",
    "MaxLen",
    "MinLen",
    "MultipleOf",
    "MutableMapping",
    "MutableSequence",
    "MutableSet",
    "N",
    "NamedTuple",
    "NewType",
    "NoReturn",
    "NoneBytes",
    "NoneStr",
    "NoneStrBytes",
    "NoneType",
    "NotRequired",
    "Null",
    "Number",
    "ONE",
    "OpenBinaryMode",
    "OpenBinaryModeReading",
    "OpenBinaryModeUpdating",
    "OpenBinaryModeWriting",
    "OpenTextMode",
    "OpenTextModeReading",
    "OpenTextModeUpdating",
    "OpenTextModeWriting",
    "Opt",
    "OptFloat",
    "OptInt",
    "OptStr",
    "Optional",
    "OptionalFloat",
    "OptionalInt",
    "OptionalStr",
    "OrderedDict",
    "P",
    "PT",
    "ParamSpec",
    "ParamSpecArgs",
    "ParamSpecKwargs",
    "Path",
    "PathLike",
    "PathLikeAny",
    "PathLikeBytes",
    "PathLikeStr",
    "Predicate",
    "Protocol",
    "R",
    "RT",
    "Required",
    "ReturnT",
    "ReturnType",
    "Reversible",
    "STDIN",
    "STDIO",
    "Self",
    "Seq",
    "Sequence",
    "Set",
    "SetAny",
    "SetFloat",
    "SetInt",
    "SetNumber",
    "SetStr",
    "SetT",
    "ShapeType",
    "Sized",
    "StrBytes",
    "StrEnum",
    "StrIntFloat",
    "StrOrBytesPath",
    "StrPath",
    "StringEnum",
    "SupportsAbs",
    "SupportsBytes",
    "SupportsComplex",
    "SupportsFloat",
    "SupportsIndex",
    "SupportsInt",
    "SupportsRound",
    "T",
    "TRUE",
    "TYPE_CHECKING",
    "T_ParamSpec",
    "T_Retval",
    "T_co",
    "T_contra",
    "Text",
    "Timezone",
    "Tuple",
    "TupleStrStr",
    "TupleStrs",
    "Txt",
    "Type",
    "TypeAlias",
    "TypeGuard",
    "TypeVar",
    "TypeVarTuple",
    "TypedDict",
    "U",
    "Union",
    "Unpack",
    "UpperCase",
    "VT",
    "VT_co",
    "VT_contra",
    "V_co",
    "ValT",
    "ValType",
    "ValuesView",
    "ZERO",
    "_DT",
    "_KT",
    "_KT_co",
    "_KT_contra",
    "_R",
    "_RT",
    "_T",
    "_T_co",
    "_T_contra",
    "_VT",
    "_VT_co",
    "_VT_contra",
    "_V_co",
    "__all_annotated_types__",
    "__all_shed__",
    "__all_typing__",
    "__all_typing_extensions__",
    "__all_typing_extensions_future__",
    "__version__",
    "annotated_types",
    "annotations",
    "cast",
    "final",
    "get_args",
    "get_origin",
    "get_type_hints",
    "no_type_check",
    "no_type_check_decorator",
    "null",
    "overload",
    "runtime",
    "runtime_checkable",
    "typing",
    "typing_extensions",
)
